@@ -120,7 +120,13 @@ def process_file_response(response, destination, progress_bar=False):
         fp = open(destination, 'wb')
         is_file = True
 
-    total_length = int(response.headers.get('content-length'))
+    content_length = response.headers.get('content-length')
+    if content_length:
+        total_length = int(content_length)
+    else:
+        total_length = 0
+        progress_bar = False
+
     chunk, chunk_size = 1, 1024
 
     for chunk in tqdm(
