@@ -151,6 +151,17 @@ def configurations(ctx, retailer):
         raise click.ClickException(str(exc))
 
 
+@api.command()
+@click.argument('retailer')
+@pass_rebotics_context
+def mobile_configurations(ctx, retailer):
+    """
+    Fetch configurations for mobile application for retailer
+    """
+    res = ctx.provider.get_mobile_configurations(retailer)
+    ctx.format_result(res)
+
+
 @api.command()
 @click.option('-n', '--notify', is_flag=True)
 @click.option('-d', '--delay', type=click.INT, default=60)
