@@ -2,6 +2,8 @@ import csv
 import json
 import logging
 import os
+import pathlib
+import shutil
 import webbrowser
 from copy import copy
 from datetime import datetime
@@ -30,7 +32,7 @@ logger = logging.getLogger(__name__)
 @click.group()
 @click.option('-f', '--format', default='table', type=click.Choice(['table', 'id', 'json']))
 @click.option('-v', '--verbose', is_flag=True, help='Enables verbose mode')
-@click.option('-c', '--config', type=click.Path(), default='retailers.json', help="Specify what config.json to use")
+@click.option('-c', '--config', type=click.Path(), default='retailer.json', help="Specify what config.json to use")
 @click.option('-r', '--role', default=lambda: read_saved_role('retailer'), help="Key to specify what retailer to use")
 @click.version_option()
 @click.pass_context
@@ -39,6 +41,7 @@ def api(ctx, format, verbose, config, role):
     Retailer CLI tool to communicate with retailer API
     """
     process_role(ctx, role, 'retailer')
+
     ctx.obj = ReboticsCLIContext(
         role,
         format,
@@ -123,6 +126,28 @@ def export_to_dataset(ctx, processing_ids, batch_size):
         raise click.ClickException(str(exc.response.json()))
 
 
+@api.command()
+@click.argument('processing_ids', required=True, nargs=-1, type=click.INT)
+@click.option('-q', '--image-quality', type=int, default=70,
+              help="Jpeg image quality between 0 and 100. Default is 70.")
+@click.option('-s', '--segment-size', type=int, default=20,
+              help="Number of images in job. Set 0 to not split task into jobs.")
+@pass_rebotics_context
+def export_to_cvat(ctx, processing_ids, image_quality, segment_size):
+    if ctx.verbose:
+        click.echo('Exporting scans to CVAT: {}'.format(processing_ids), err=True)
+
+    try:
+        if ctx.verbose:
+            click.echo('Sending request...')
+        response = ctx.provider.export_to_cvat(processing_ids, image_quality, segment_size)
+        click.echo('Queued to export to CVAT: {}'.format(response))
+    except ProviderHTTPClientException as exc:
+        if ctx.verbose:
+            logger.exception(exc)
+        raise click.ClickException(str(exc.response.json()))
+
+
 @api.command()
 @click.argument('processing_ids', required=True, nargs=-1, type=click.INT)
 @click.option('-c', '--concurrency', type=int, default=4)
