@@ -107,6 +107,26 @@ class AdminProvider(ReboticsBaseProvider):
     def get_configurations_by_retailer_authentication(self, **kwargs):
         return self.session.get()
 
+    @remote_service('/retailers/host/{codename}/configurations/mobile/')
+    def get_mobile_configurations_by_codename(self, codename, **kwargs):
+        """API to retrieve mobile configurations by codename"""
+        return self.session.get(codename=codename)
+
+    @remote_service('retailers/configurations/mobile/')
+    def get_mobile_configurations_by_retailer_authentication(self, **kwargs):
+        """API to retrieve mobile configurations for authenticated service"""
+        return self.session.get()
+
+    def get_mobile_configurations(self, codename=None):
+        """ retrieve configurations for mobile application
+        """
+        if codename is not None and not self.is_retailer_identifier_used():
+            return self.get_mobile_configurations_by_codename(codename)
+        elif self.is_retailer_identifier_used():
+            return self.get_mobile_configurations_by_retailer_authentication()
+        else:
+            raise ProviderHTTPClientException('You did not use any of the authentication methods to get configurations')
+
     # deprecated
     @remote_service('/api/classification_data/import/')
     def create_classification_database_import(self, retailer, model, extension='zip', **kwargs):
