@@ -440,6 +440,14 @@ class RetailerProvider(ReboticsBaseProvider):
             'batch_size': batch_size,
         })
 
+    @remote_service('api/v4/processing/actions/export-to-cvat/')
+    def export_to_cvat(self, scan_ids, image_quality=70, segment_size=20, **kwargs):
+        return self.session.post(json={
+            'scans': sorted(list(set(scan_ids))),
+            'image_quality': image_quality,
+            'segment_size': segment_size,
+        })
+
     @remote_service('/api/v1/rebotics/rpc/export-feature-vector/')
     def feature_vectors_export(self):
         return FeatureVectorFlow(self, self.session)
